@@ -585,11 +585,11 @@ impl VoteState {
         Ok(())
     }
 
-    pub fn is_uninitialized_no_deser(data: &[u8]) -> bool {
+    pub fn is_correct_size_and_initialized(data: &[u8]) -> bool {
         const VERSION_OFFSET: usize = 4;
-        data.len() != VoteState::size_of()
-            || data[VERSION_OFFSET..VERSION_OFFSET + DEFAULT_PRIOR_VOTERS_OFFSET]
-                == [0; DEFAULT_PRIOR_VOTERS_OFFSET]
+        data.len() == VoteState::size_of()
+            && data[VERSION_OFFSET..VERSION_OFFSET + DEFAULT_PRIOR_VOTERS_OFFSET]
+                != [0; DEFAULT_PRIOR_VOTERS_OFFSET]
     }
 }
 
@@ -2082,25 +2082,31 @@ mod tests {
     }
 
     #[test]
-    fn test_is_uninitialized_no_deser() {
+    fn test_is_correct_size_and_initialized() {
         // Check all zeroes
         let mut vote_account_data = vec![0; VoteState::size_of()];
-        assert!(VoteState::is_uninitialized_no_deser(&vote_account_data));
+        assert!(!VoteState::is_correct_size_and_initialized(
+            &vote_account_data
+        ));
 
         // Check default VoteState
         let default_account_state = VoteStateVersions::new_current(VoteState::default());
         VoteState::serialize(&default_account_state, &mut vote_account_data).unwrap();
-        assert!(VoteState::is_uninitialized_no_deser(&vote_account_data));
+        assert!(!VoteState::is_correct_size_and_initialized(
+            &vote_account_data
+        ));
 
         // Check non-zero data shorter than offset index used
         let short_data = vec![1; DEFAULT_PRIOR_VOTERS_OFFSET];
-        assert!(VoteState::is_uninitialized_no_deser(&short_data));
+        assert!(!VoteState::is_correct_size_and_initialized(&short_data));
 
         // Check non-zero large account
         let mut large_vote_data = vec![1; 2 * VoteState::size_of()];
         let default_account_state = VoteStateVersions::new_current(VoteState::default());
         VoteState::serialize(&default_account_state, &mut large_vote_data).unwrap();
-        assert!(VoteState::is_uninitialized_no_deser(&vote_account_data));
+        assert!(!VoteState::is_correct_size_and_initialized(
+            &vote_account_data
+        ));
 
         // Check populated VoteState
         let account_state = VoteStateVersions::new_current(VoteState::new(
@@ -2113,6 +2119,8 @@ mod tests {
             &Clock::default(),
         ));
         VoteState::serialize(&account_state, &mut vote_account_data).unwrap();
-        assert!(!VoteState::is_uninitialized_no_deser(&vote_account_data));
+        assert!(VoteState::is_correct_size_and_initialized(
+            &vote_account_data
+        ));
     }
 }
